**Example 1: ModifyCustomizeTemplateVersionControl**



Input: 

```
tccli cloudstudio ModifyCustomizeTemplateVersionControl --cli-unfold-argument  \
    --Url https:%2F%2Fgithub.com%2Fformulahendry%2F955.WLB.git \
    --CloudStudioSessionTeam cloudstudio-devops \
    --TemplateId 1
```

Output: 
```
{
    "Response": {
        "Data": null,
        "RequestId": "57aaf569-f428-4593-a200-4072023d5377"
    }
}
```

